@@ -71,6 +71,11 @@ Debian_SuSE_ppp() {
 IFUPDOWN=0
 PRODUCTS=
 
+#
+# The installer may alter this
+#
+. /usr/share/shorewall/shorewallrc
+
 if [ -f /etc/default/shorewall-init ]; then
     . /etc/default/shorewall-init
 elif [ -f /etc/sysconfig/shorewall-init ]; then
@@ -101,15 +106,11 @@ if [ -f /etc/debian_version ]; then
 	    else
 		exit 0
 	    fi
-
-	    case "$PHASE" in
-		pre-*)
-		    exit 0
-		    ;;
-	    esac
 	    ;;
     esac
 elif [ -f /etc/SuSE-release ]; then
+    PHASE=''
+
     case $0 in
 	/etc/ppp*)
 	    #
@@ -141,6 +142,8 @@ else
     #
     # Assume RedHat/Fedora/CentOS/Foobar/...
     #
+    PHASE=''
+
     case $0 in
 	/etc/ppp*)
 	    INTERFACE="$1"
@@ -181,59 +184,11 @@ else
     esac
 fi
 
+[ -n "$LOGFILE" ] || LOGFILE=/dev/null
+
 for PRODUCT in $PRODUCTS; do
-    VARDIR=/var/lib/$PRODUCT
-    [ -f /etc/$PRODUCT/vardir ] && . /etc/$PRODUCT/vardir
-
-    if [ -x $VARDIR/firewall ]; then
-	g_program=$PRODUCT
-
-	case $PRODUCT in
-	    shorewall)
-		SHAREDIR=/usr/share/shorewall
-		CONFDIR=/etc/shorewall
-		g_product="Shorewall"
-		g_family=4
-		g_tool=
-		g_basedir=/usr/share/shorewall
-		g_lite=
-		;;
-	    shorewall6)
-		SHAREDIR=/usr/share/shorewall6
-		CONFDIR=/etc/shorewall6
-		g_product="Shorewall6"
-		g_family=6
-		g_tool=
-		g_basedir=/usr/share/shorewall
-		g_lite=
-		;;
-	    shorewall-lite)
-		SHAREDIR=/usr/share/shorewall-lite
-		CONFDIR=/etc/shorewall-lite
-		g_product="Shorewall Lite"
-		g_family=4
-		g_base=shorewall
-		g_tool=iptables
-		g_basedir=/usr/share/shorewall-lite
-		g_lite=Yes
-		;;
-	    shorewall6-lite)
-		SHAREDIR=/usr/share/shorewall6-lite
-		CONFDIR=/etc/shorewall6-lite
-		g_product="Shorewall6 Lite"
-		g_family=6
-		g_base=shorewall6
-		g_tool=ip6tables
-		g_basedir=/usr/share/shorewall6-lite
-		g_lite=Yes
-		;;
-	esac
-
-	( . /usr/share/$PRODUCT/lib.base
-	    mutex_on
-	    ${VARDIR}/firewall -V0 $COMMAND $INTERFACE || echo_notdone
-	    mutex_off
-	  )
+    if [ -x $VARDIR/$PRODUCT/firewall ]; then
+	  ( ${VARDIR}/$PRODUCT/firewall -V0 $COMMAND $INTERFACE >> $LOGFILE 2>&1 ) || true
     fi
 done
 
